@@ -1,4 +1,4 @@
-if [ ! -f /etc/X11/spiceqxl.xorg.conf ]
+if [ ! -e /etc/X11/spiceqxl.xorg.conf ]
 then
     /usr/bin/mkdir -p /etc/X11
     /usr/bin/cp /etc/defaults/etc/X11/spiceqxl.xorg.conf /etc/X11/spiceqxl.xorg.conf
